==> hyades.source_3.0.0_20040621_1225.zip: org/eclipse/hyades/uml2sd/ui/actions/OpenSDFiltersDialog.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.ui.actions;

import org.eclipse.hyades.uml2sd.ui.SDViewerPlugin;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider;
import org.eclipse.hyades.uml2sd.ui.actions.widgets.FilterListDialog;
import org.eclipse.hyades.uml2sd.ui.view.SDView;
import org.eclipse.jface.action.Action;

/**
 * Action delegate for 'Filter' on a message
 */
public class OpenSDFiltersDialog extends Action {

	private SDView view;	
	private ISDFilterProvider provider;

	/**
	 * @param view_
	 */
	public OpenSDFiltersDialog(SDView view_, ISDFilterProvider provider_) {
		super(SDViewerPlugin.getResourceString("POPUP_MENU_FILTER"));//$NON-NLS-1$
		setImageDescriptor(SDViewerPlugin.getResourceImage("filter_obj.gif")); //$NON-NLS-1$
		setId("org.eclipse.hyades.uml2sd.ui.sdFilters"); //$NON-NLS-1$
		setToolTipText(SDViewerPlugin.getResourceString("POPUP_MENU_FILTER"));//$NON-NLS-1
		view = view_;
		provider = provider_;
	}
	
	/**
	 * @see org.eclipse.jface.action.IAction#run()
	 */
	public void run() {
		if (view == null) {
			return;
		}
		FilterListDialog dialog = new FilterListDialog(view, provider);
		dialog.open();
	}
	
}

==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/uml2sd/ui/actions/OpenSDFiltersDialog.java <==
/**********************************************************************
 * Copyright (c) 2004 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.uml2sd.ui.actions;

import org.eclipse.hyades.uml2sd.ui.SDViewerPlugin;
import org.eclipse.hyades.uml2sd.ui.actions.provider.ISDFilterProvider;
import org.eclipse.hyades.uml2sd.ui.actions.widgets.FilterListDialog;
import org.eclipse.hyades.uml2sd.ui.view.SDView;
import org.eclipse.jface.action.Action;

/**
 * Action delegate for 'Filter' on a message
 */
public class OpenSDFiltersDialog extends Action {

	private SDView view;	
	private ISDFilterProvider provider;

	/**
	 * @param view_
	 */
	public OpenSDFiltersDialog(SDView view_, ISDFilterProvider provider_) {
		super(SDViewerPlugin.getResourceString("POPUP_MENU_FILTER"));//$NON-NLS-1$
		setImageDescriptor(SDViewerPlugin.getResourceImage("filter_obj.gif")); //$NON-NLS-1$
		setId("org.eclipse.hyades.uml2sd.ui.sdFilters"); //$NON-NLS-1$
		setToolTipText(SDViewerPlugin.getResourceString("POPUP_MENU_FILTER"));//$NON-NLS-1$
		view = view_;
		provider = provider_;
	}
	
	/**
	 * @see org.eclipse.jface.action.IAction#run()
	 */
	public void run() {
		if (view == null) {
			return;
		}
		FilterListDialog dialog = new FilterListDialog(view, provider);
		dialog.open();
	}
	
}
